# Jigsaw
[![Build Status](https://travis-ci.org/nint8835/jigsaw.svg?branch=master)](https://travis-ci.org/nint8835/jigsaw)
[![Documentation Status](https://readthedocs.org/projects/jigsaw/badge/?version=latest)](http://jigsaw.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/nint8835/jigsaw/branch/master/graph/badge.svg)](https://codecov.io/gh/nint8835/jigsaw)
[![Code Climate](https://lima.codeclimate.com/github/nint8835/jigsaw/badges/gpa.svg)](https://lima.codeclimate.com/github/nint8835/jigsaw)

A powerful, simple to implement plugin loader and management framework for Python 3.6+

## Installation
To install jigsaw, simply run:

	pip install jigsaw
    
## Implementation
An example of implementing jigsaw into a program can be found in the [example folder](https://github.com/nint8835/jigsaw/tree/master/example)

## Projects using jigsaw
* [NintbotForDiscord](https://github.com/nint8835/NintbotForDiscord) - A modular bot framework for the voice and text chat service, Discord
* [Chainmail](https://github.com/Chainmail-Project/Chainmail) - A wrapper for the vanilla Minecraft server providing basic modding support
* [Mercury](https://github.com/nint8835/Mercury) - A modular IRC bot framework